@@ -262,6 +262,7 @@ create_PropertiesWindow (UIComponents *uic)
 
   PropertiesWindow = gtk_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (PropertiesWindow), _("Grcm Preferences"));
+  gtk_window_set_transient_for (GTK_WINDOW (PropertiesWindow), GTK_WINDOW (uic->MainWindow));
   gtk_window_set_modal (GTK_WINDOW (PropertiesWindow), TRUE);
 
   dialog_vbox1 = GTK_DIALOG (PropertiesWindow)->vbox;
@@ -426,7 +427,7 @@ create_MainWindowPopupMenu (UIComponents *uic, gboolean sensitive)
 	MainWindowPopupMenu = gtk_menu_new ();
 	
 	menuItem = gtk_image_menu_item_new_with_label (_("Connect"));
-	image = gtk_image_new_from_file ("grcm/connect-16.png");
+	image = gtk_image_new_from_file ("connect-16.png");
 	gtk_image_menu_item_set_image(GTK_IMAGE_MENU_ITEM(menuItem), image);
 	g_signal_connect (G_OBJECT (menuItem), "activate", G_CALLBACK (on_popup_execute_activated), (gpointer) uic);
 	gtk_menu_append(MainWindowPopupMenu, menuItem);
@@ -492,6 +493,7 @@ create_ConnectionsWindow (UIComponents *uic)
 
   ConnectionsWindow = gtk_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (ConnectionsWindow), _("Grcm - Edit Connections"));
+  gtk_window_set_transient_for (GTK_WINDOW (ConnectionsWindow), GTK_WINDOW (uic->MainWindow));
   gtk_window_set_modal (GTK_WINDOW (ConnectionsWindow), TRUE);
 
   dialog_vbox2 = GTK_DIALOG (ConnectionsWindow)->vbox;
@@ -739,6 +741,8 @@ create_ConnectionTypesWindow (UIComponents *uic)
 
   ConnectionTypesWindow = gtk_dialog_new ();
   gtk_window_set_title (GTK_WINDOW (ConnectionTypesWindow), _("Grcm - Edit connection Types"));
+  gtk_window_set_transient_for (GTK_WINDOW (ConnectionTypesWindow), GTK_WINDOW (uic->MainWindow));
+  gtk_window_set_modal (GTK_WINDOW (ConnectionTypesWindow), TRUE);
 
   dialog_vbox3 = GTK_DIALOG (ConnectionTypesWindow)->vbox;
   gtk_widget_show (dialog_vbox3);
